Introduction — XlsxWriter Documentation

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »

# Introduction

XlsxWriter is a Python module for writing files in the Excel 2007+ XLSX file format.

It can be used to write text, numbers, and formulas to multiple worksheets and it supports features such as formatting, images, page setup, autofilters, conditional formatting and many others.

This module cannot be used to modify or write to an existing Excel XLSX file. There are some Alternative modules for handling Excel files Python modules that do that.

XlsxWriter is written by John McNamara who also wrote the perl modules Excel::Writer::XLSX and Spreadsheet::WriteExcel and who is the maintainer of Spreadsheet::ParseExcel. The XlsxWriter module is a port of Excel::Writer::XLSX. See Comparison with Excel::Writer::XLSX for a list of currently ported features.

XlsxWriter is intended to have a high degree of compatibility with files produced by Excel. In most cases the files produced are 100% equivalent to files produced by Excel and the test suite contains a large number of test cases that verify the output of XlsxWriter against actual files created in Excel.

XlsxWriter is licensed under a BSD License and is available as a `git` repository on GitHub.

### Navigation

- index
- next |
- previous |
- XlsxWriter Documentation »